summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--png.c6
-rw-r--r--png.h25
-rw-r--r--pngconf.h2
-rw-r--r--pngcrush.c2
-rw-r--r--pnglibconf.h4
-rw-r--r--pngrtran.c4
-rw-r--r--pngrutil.c4
7 files changed, 25 insertions, 22 deletions
diff --git a/png.c b/png.c
index 7934623d2..dffcbb672 100644
--- a/png.c
+++ b/png.c
@@ -14,7 +14,7 @@
#include "pngpriv.h"
/* Generate a compiler error if there is an old png.h in the search path. */
-typedef png_libpng_version_1_5_15 Your_png_h_is_not_version_1_5_15;
+typedef png_libpng_version_1_5_16 Your_png_h_is_not_version_1_5_16;
/* Tells libpng that we have already handled the first "num_bytes" bytes
* of the PNG file signature. If the PNG data is embedded into another
@@ -658,13 +658,13 @@ png_get_copyright(png_const_structp png_ptr)
#else
# ifdef __STDC__
return PNG_STRING_NEWLINE \
- "libpng version 1.5.15 - March 28, 2013" PNG_STRING_NEWLINE \
+ "libpng version 1.5.16 - May 23, 2013" PNG_STRING_NEWLINE \
"Copyright (c) 1998-2013 Glenn Randers-Pehrson" PNG_STRING_NEWLINE \
"Copyright (c) 1996-1997 Andreas Dilger" PNG_STRING_NEWLINE \
"Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc." \
PNG_STRING_NEWLINE;
# else
- return "libpng version 1.5.15 - March 28, 2013\
+ return "libpng version 1.5.16 - May 23, 2013\
Copyright (c) 1998-2013 Glenn Randers-Pehrson\
Copyright (c) 1996-1997 Andreas Dilger\
Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc.";
diff --git a/pngconf.h b/pngconf.h
index 34caef547..832d4da62 100644
--- a/pngconf.h
+++ b/pngconf.h
@@ -1,7 +1,7 @@
/* pngconf.h - machine configurable file for libpng
*
- * libpng version 1.5.15 - March 28, 2013
+ * libpng version 1.5.16 - May 23, 2013
*
* Copyright (c) 1998-2013 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/pngcrush.c b/pngcrush.c
index 7fc212931..d54aa9b46 100644
--- a/pngcrush.c
+++ b/pngcrush.c
@@ -307,7 +307,7 @@
Change log:
-Version 1.7.59 (built with libpng-1.5.15 and zlib-1.2.8)
+Version 1.7.59 (built with libpng-1.5.16 and zlib-1.2.8)
Show the acTL chunk in the chunk list in verbose output.
Fixed several bugs reported by pornel at users.sf.net:
Do not call png_set_benign_errors when PNG_BENIGN_ERRORS_SUPPORTED
diff --git a/pnglibconf.h b/pnglibconf.h
index 3614ad8d7..d2a6eee09 100644
--- a/pnglibconf.h
+++ b/pnglibconf.h
@@ -1,7 +1,7 @@
-/* 1.5.15 STANDARD API DEFINITION */
+/* 1.5.16 STANDARD API DEFINITION */
/* pnglibconf.h - library build configuration */
-/* libpng version 1.5.15 - March 28, 2013 */
+/* libpng version 1.5.16 - May 23, 2013 */
/* Copyright (c) 1998-2013 Glenn Randers-Pehrson */
diff --git a/pngrtran.c b/pngrtran.c
index 7adb1466e..5673193cf 100644
--- a/pngrtran.c
+++ b/pngrtran.c
@@ -1,7 +1,7 @@
/* pngrtran.c - transforms the data in a row for PNG readers
*
- * Last changed in libpng 1.5.15 [March 28, 2013]
+ * Last changed in libpng 1.5.16 [May 23, 2013]
* Copyright (c) 1998-2013 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -194,6 +194,8 @@ translate_gamma_flags(png_structp png_ptr, png_fixed_point output_gamma,
*/
# ifdef PNG_READ_sRGB_SUPPORTED
png_ptr->flags |= PNG_FLAG_ASSUME_sRGB;
+# else
+ PNG_UNUSED(png_ptr)
# endif
if (is_screen)
output_gamma = PNG_GAMMA_sRGB;
diff --git a/pngrutil.c b/pngrutil.c
index 649ecc21e..802ff2083 100644
--- a/pngrutil.c
+++ b/pngrutil.c
@@ -1,7 +1,7 @@
/* pngrutil.c - utilities to read a PNG file
*
- * Last changed in libpng 1.5.15 [March 28, 2013]
+ * Last changed in libpng 1.5.16 [May 23, 2013]
* Copyright (c) 1998-2013 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -18,8 +18,6 @@
#ifdef PNG_READ_SUPPORTED
-#define png_strtod(p,a,b) strtod(a,b)
-
png_uint_32 PNGAPI
png_get_uint_31(png_structp png_ptr, png_const_bytep buf)
{
diff --git a/png.h b/png.h
index 0134c318a..c3ac5c7d6 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
* libpng version 1.5.15 - March 28, 2013
* Copyright (c) 1998-2013 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -11,7 +11,7 @@
* Authors and maintainers:
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
* libpng versions 0.97, January 1998, through 1.5.15 - March 28, 2013: Glenn
* See also "Contributing Authors", below.
*
* Note about libpng version numbers:
@@ -184,9 +184,12 @@
* 1.5.14beta01-08 15 10514 15.so.15.14[.0]
* 1.5.14rc01-03 15 10514 15.so.15.14[.0]
* 1.5.14 15 10514 15.so.15.14[.0]
- * 1.5.15beta01-10 15 10515 15.so.15.15[.0]
+ * 1.5.15beta01-09 15 10515 15.so.15.15[.0]
* 1.5.15rc01 15 10515 15.so.15.15[.0]
* 1.5.15 15 10515 15.so.15.15[.0]
+ * 1.5.16beta01-06 15 10516 15.so.15.16[.0]
+ * 1.5.16rc01 15 10516 15.so.15.16[.0]
+ * 1.5.16 15 10516 15.so.15.16[.0]
*
* Henceforth the source version will match the shared-library major
* and minor numbers; the shared-library major version number will be
@@ -218,7 +221,7 @@
*
* This code is released under the libpng license.
*
* libpng versions 1.2.6, August 15, 2004, through 1.5.15, March 28, 2013, are
* Copyright (c) 2004, 2006-2013 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
* with the following individual added to the list of Contributing Authors:
@@ -330,13 +333,13 @@
* Y2K compliance in libpng:
* =========================
*
- * March 28, 2013
+ * May 23, 2013
*
* Since the PNG Development group is an ad-hoc body, we can't make
* an official declaration.
*
* This is your unofficial assurance that libpng from version 0.71 and
* upward through 1.5.15 are Y2K compliant. It is my belief that
* earlier versions were also Y2K compliant.
*
* Libpng only has two year fields. One is a 2-byte unsigned integer
@@ -395,9 +398,9 @@
*/
/* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "1.5.15"
+#define PNG_LIBPNG_VER_STRING "1.5.16"
#define PNG_HEADER_VERSION_STRING \
- " libpng version 1.5.15 - March 28, 2013\n"
+ " libpng version 1.5.16 - May 23, 2013\n"
#define PNG_LIBPNG_VER_SONUM 15
#define PNG_LIBPNG_VER_DLLNUM 15
@@ -405,7 +408,7 @@
/* These should match the first 3 components of PNG_LIBPNG_VER_STRING: */
#define PNG_LIBPNG_VER_MAJOR 1
#define PNG_LIBPNG_VER_MINOR 5
-#define PNG_LIBPNG_VER_RELEASE 15
+#define PNG_LIBPNG_VER_RELEASE 16
/* This should match the numeric part of the final component of
* PNG_LIBPNG_VER_STRING, omitting any leading zero:
@@ -436,7 +439,7 @@
* version 1.0.0 was mis-numbered 100 instead of 10000). From
* version 1.0.1 it's xxyyzz, where x=major, y=minor, z=release
*/
-#define PNG_LIBPNG_VER 10515 /* 1.5.15 */
+#define PNG_LIBPNG_VER 10516 /* 1.5.16 */
/* Library configuration: these options cannot be changed after
* the library has been built.
@@ -558,7 +561,7 @@ extern "C" {
/* This triggers a compiler error in png.c, if png.c and png.h
* do not agree upon the version number.
*/
-typedef char* png_libpng_version_1_5_15;
+typedef char* png_libpng_version_1_5_16;
/* Three color definitions. The order of the red, green, and blue, (and the
* exact size) is not important, although the size of the fields need to
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
- * libpng version 1.5.15 - March 28, 2013
+ * libpng version 1.5.16 - May 23, 2013
* Copyright (c) 1998-2013 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -11,7 +11,7 @@
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- * libpng versions 0.97, January 1998, through 1.5.15 - March 28, 2013: Glenn
+ * libpng versions 0.97, January 1998, through 1.5.16 - May 23, 2013: Glenn
* See also "Contributing Authors", below.
*
@@ -218,7 +221,7 @@
* This code is released under the libpng license.
*
- * libpng versions 1.2.6, August 15, 2004, through 1.5.15, March 28, 2013, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.5.16, May 23, 2013, are
* Copyright (c) 2004, 2006-2013 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
@@ -330,13 +333,13 @@
*
* This is your unofficial assurance that libpng from version 0.71 and
- * upward through 1.5.15 are Y2K compliant. It is my belief that
+ * upward through 1.5.16 are Y2K compliant. It is my belief that
* earlier versions were also Y2K compliant.
*